==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkWindow.java <==
// java wrapper for vtkWindow object
//

package vtk;
import vtk.*;

public class vtkWindow extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWindowInfo_2(String id0);
  public void SetWindowInfo(String id0)
    { SetWindowInfo_2(id0); }

  private native void SetParentInfo_3(String id0);
  public void SetParentInfo(String id0)
    { SetParentInfo_3(id0); }

  private native int[]  GetPosition_4();
  public int[]  GetPosition()
    { return GetPosition_4(); }

  private native void SetPosition_5(int id0,int id1);
  public void SetPosition(int id0,int id1)
    { SetPosition_5(id0,id1); }

  private native void SetPosition_6(int id0[]);
  public void SetPosition(int id0[])
    { SetPosition_6(id0); }

  private native int[]  GetSize_7();
  public int[]  GetSize()
    { return GetSize_7(); }

  private native void SetSize_8(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_8(id0,id1); }

  private native void SetSize_9(int id0[]);
  public void SetSize(int id0[])
    { SetSize_9(id0); }

  private native int[]  GetScreenSize_10();
  public int[]  GetScreenSize()
    { return GetScreenSize_10(); }

  private native void SetMapped_11(int id0);
  public void SetMapped(int id0)
    { SetMapped_11(id0); }

  private native int GetMapped_12();
  public int GetMapped()
    { return GetMapped_12(); }

  private native void MappedOn_13();
  public void MappedOn()
    { MappedOn_13(); }

  private native void MappedOff_14();
  public void MappedOff()
    { MappedOff_14(); }

  private native void SetErase_15(int id0);
  public void SetErase(int id0)
    { SetErase_15(id0); }

  private native int GetErase_16();
  public int GetErase()
    { return GetErase_16(); }

  private native void EraseOn_17();
  public void EraseOn()
    { EraseOn_17(); }

  private native void EraseOff_18();
  public void EraseOff()
    { EraseOff_18(); }

  private native void SetDoubleBuffer_19(int id0);
  public void SetDoubleBuffer(int id0)
    { SetDoubleBuffer_19(id0); }

  private native int GetDoubleBuffer_20();
  public int GetDoubleBuffer()
    { return GetDoubleBuffer_20(); }

  private native void DoubleBufferOn_21();
  public void DoubleBufferOn()
    { DoubleBufferOn_21(); }

  private native void DoubleBufferOff_22();
  public void DoubleBufferOff()
    { DoubleBufferOff_22(); }

  private native String GetWindowName_23();
  public String GetWindowName()
    { return GetWindowName_23(); }

  private native void SetWindowName_24(String id0);
  public void SetWindowName(String id0)
    { SetWindowName_24(id0); }

  private native void Render_25();
  public void Render()
    { Render_25(); }

  private native int GetPixelData_26(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5);
  public int GetPixelData(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5)
    { return GetPixelData_26(id0,id1,id2,id3,id4,id5); }

  private native int GetDPI_27();
  public int GetDPI()
    { return GetDPI_27(); }

  private native void SetDPI_28(int id0);
  public void SetDPI(int id0)
    { SetDPI_28(id0); }

  private native int GetDPIMinValue_29();
  public int GetDPIMinValue()
    { return GetDPIMinValue_29(); }

  private native int GetDPIMaxValue_30();
  public int GetDPIMaxValue()
    { return GetDPIMaxValue_30(); }

  private native boolean DetectDPI_31();
  public boolean DetectDPI()
    { return DetectDPI_31(); }

  private native void SetOffScreenRendering_32(int id0);
  public void SetOffScreenRendering(int id0)
    { SetOffScreenRendering_32(id0); }

  private native int GetOffScreenRendering_33();
  public int GetOffScreenRendering()
    { return GetOffScreenRendering_33(); }

  private native void OffScreenRenderingOn_34();
  public void OffScreenRenderingOn()
    { OffScreenRenderingOn_34(); }

  private native void OffScreenRenderingOff_35();
  public void OffScreenRenderingOff()
    { OffScreenRenderingOff_35(); }

  private native void MakeCurrent_36();
  public void MakeCurrent()
    { MakeCurrent_36(); }

  private native void SetTileScale_37(int id0,int id1);
  public void SetTileScale(int id0,int id1)
    { SetTileScale_37(id0,id1); }

  private native void SetTileScale_38(int id0[]);
  public void SetTileScale(int id0[])
    { SetTileScale_38(id0); }

  private native int[]  GetTileScale_39();
  public int[]  GetTileScale()
    { return GetTileScale_39(); }

  private native void SetTileScale_40(int id0);
  public void SetTileScale(int id0)
    { SetTileScale_40(id0); }

  private native void SetTileViewport_41(double id0,double id1,double id2,double id3);
  public void SetTileViewport(double id0,double id1,double id2,double id3)
    { SetTileViewport_41(id0,id1,id2,id3); }

  private native void SetTileViewport_42(double id0[]);
  public void SetTileViewport(double id0[])
    { SetTileViewport_42(id0); }

  private native double[] GetTileViewport_43();
  public double[] GetTileViewport()
    { return GetTileViewport_43(); }

  public vtkWindow() { super(); }

  public vtkWindow(long id) { super(id); }

}

==> vtk-8.1.2-1-armv7h.pkg.tar.xz: vtk/vtkWindow.java <==
// java wrapper for vtkWindow object
//

package vtk;
import vtk.*;

public class vtkWindow extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWindowInfo_2(String id0);
  public void SetWindowInfo(String id0)
    { SetWindowInfo_2(id0); }

  private native void SetParentInfo_3(String id0);
  public void SetParentInfo(String id0)
    { SetParentInfo_3(id0); }

  private native int[]  GetPosition_4();
  public int[]  GetPosition()
    { return GetPosition_4(); }

  private native void SetPosition_5(int id0,int id1);
  public void SetPosition(int id0,int id1)
    { SetPosition_5(id0,id1); }

  private native void SetPosition_6(int id0[]);
  public void SetPosition(int id0[])
    { SetPosition_6(id0); }

  private native int[]  GetSize_7();
  public int[]  GetSize()
    { return GetSize_7(); }

  private native void SetSize_8(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_8(id0,id1); }

  private native void SetSize_9(int id0[]);
  public void SetSize(int id0[])
    { SetSize_9(id0); }

  private native int[]  GetScreenSize_10();
  public int[]  GetScreenSize()
    { return GetScreenSize_10(); }

  private native void SetMapped_11(int id0);
  public void SetMapped(int id0)
    { SetMapped_11(id0); }

  private native int GetMapped_12();
  public int GetMapped()
    { return GetMapped_12(); }

  private native void MappedOn_13();
  public void MappedOn()
    { MappedOn_13(); }

  private native void MappedOff_14();
  public void MappedOff()
    { MappedOff_14(); }

  private native void SetErase_15(int id0);
  public void SetErase(int id0)
    { SetErase_15(id0); }

  private native int GetErase_16();
  public int GetErase()
    { return GetErase_16(); }

  private native void EraseOn_17();
  public void EraseOn()
    { EraseOn_17(); }

  private native void EraseOff_18();
  public void EraseOff()
    { EraseOff_18(); }

  private native void SetDoubleBuffer_19(int id0);
  public void SetDoubleBuffer(int id0)
    { SetDoubleBuffer_19(id0); }

  private native int GetDoubleBuffer_20();
  public int GetDoubleBuffer()
    { return GetDoubleBuffer_20(); }

  private native void DoubleBufferOn_21();
  public void DoubleBufferOn()
    { DoubleBufferOn_21(); }

  private native void DoubleBufferOff_22();
  public void DoubleBufferOff()
    { DoubleBufferOff_22(); }

  private native String GetWindowName_23();
  public String GetWindowName()
    { return GetWindowName_23(); }

  private native void SetWindowName_24(String id0);
  public void SetWindowName(String id0)
    { SetWindowName_24(id0); }

  private native void Render_25();
  public void Render()
    { Render_25(); }

  private native int GetPixelData_26(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5,int id6);
  public int GetPixelData(int id0,int id1,int id2,int id3,int id4,vtkUnsignedCharArray id5,int id6)
    { return GetPixelData_26(id0,id1,id2,id3,id4,id5,id6); }

  private native int GetDPI_27();
  public int GetDPI()
    { return GetDPI_27(); }

  private native void SetDPI_28(int id0);
  public void SetDPI(int id0)
    { SetDPI_28(id0); }

  private native int GetDPIMinValue_29();
  public int GetDPIMinValue()
    { return GetDPIMinValue_29(); }

  private native int GetDPIMaxValue_30();
  public int GetDPIMaxValue()
    { return GetDPIMaxValue_30(); }

  private native boolean DetectDPI_31();
  public boolean DetectDPI()
    { return DetectDPI_31(); }

  private native void SetOffScreenRendering_32(int id0);
  public void SetOffScreenRendering(int id0)
    { SetOffScreenRendering_32(id0); }

  private native int GetOffScreenRendering_33();
  public int GetOffScreenRendering()
    { return GetOffScreenRendering_33(); }

  private native void OffScreenRenderingOn_34();
  public void OffScreenRenderingOn()
    { OffScreenRenderingOn_34(); }

  private native void OffScreenRenderingOff_35();
  public void OffScreenRenderingOff()
    { OffScreenRenderingOff_35(); }

  private native void MakeCurrent_36();
  public void MakeCurrent()
    { MakeCurrent_36(); }

  private native void SetTileScale_37(int id0,int id1);
  public void SetTileScale(int id0,int id1)
    { SetTileScale_37(id0,id1); }

  private native void SetTileScale_38(int id0[]);
  public void SetTileScale(int id0[])
    { SetTileScale_38(id0); }

  private native int[]  GetTileScale_39();
  public int[]  GetTileScale()
    { return GetTileScale_39(); }

  private native void SetTileScale_40(int id0);
  public void SetTileScale(int id0)
    { SetTileScale_40(id0); }

  private native void SetTileViewport_41(double id0,double id1,double id2,double id3);
  public void SetTileViewport(double id0,double id1,double id2,double id3)
    { SetTileViewport_41(id0,id1,id2,id3); }

  private native void SetTileViewport_42(double id0[]);
  public void SetTileViewport(double id0[])
    { SetTileViewport_42(id0); }

  private native double[] GetTileViewport_43();
  public double[] GetTileViewport()
    { return GetTileViewport_43(); }

  public vtkWindow() { super(); }

  public vtkWindow(long id) { super(id); }

}
